module((...), lube.seeall)
local progress_manager = require("frontend.progress_manager")
function get_credits()
  local t = {}
  local v = 5000
  local inc = 5000
  for i = 1, 20 do
    t[i] = v
    v = v + inc
  end
  return t
end
lookup_event_order = {
  txt.fe_sequential_ucase,
  txt.fe_random_ucase
}
lookup_car_selection = {
  txt.fe_chosen_ucase,
  txt.fe_random_ucase,
  txt.fe_eagles_only_ucase,
  txt.fe_hosts_choice_ucase
}
lookup_powerups = {
  txt.fe_off_ucase,
  txt.ui_fe_no_respawn_ucase,
  txt.ui_fe_respawn_ucase
}
lookup_pis_purchase = {
  txt.fe_off_ucase,
  txt.fe_on_ucase
}
lookup_grid_start = {
  txt.fe_spawned_ucase,
  txt.fe_grid_ucase
}
lookup_stealing = {
  txt.fe_off_ucase,
  txt.fe_on_ucase
}
lookup_limit_car_selection = {
  txt.fe_all_cars_ucase,
  txt.fe_hosts_unlocked_cars_ucase
}
lookup_starting_credit = get_credits()
values_event_order = {"sequential", "random"}
values_car_selection = {
  "chosen",
  "random",
  "eagles_only",
  "hosts_choice"
}
values_powerups = {
  "off",
  "no_respawn",
  "respawn"
}
values_pis_purchase = {"off", "on"}
values_grid_start = {false, true}
values_stealing = {false, true}
values_limit_car_selection = {
  "all_cars",
  "hosts_unlocked_cars"
}
values_number_ai =
{
	0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16
}
lookup_number_ai =
{
	0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16
}
values_driver_model = {
  "DRIVER_BODY",
  "DRIVER_BODY_ANNIE",
  "DRIVER_BODY_ED",
  "DRIVER_BODY_GRIM",
  "DRIVER_BODY_GRIM02",
  "DRIVER_BODY_HARRY",
  "DRIVER_BODY_IVAN",
  "DRIVER_BODY_KUTTER",
  "DRIVER_BODY_NEOTWIG",
  "DRIVER_BODY_NORA",
  "DRIVER_BODY_NUTKENZ",
  "DRIVER_BODY_OTIS",
  "DRIVER_BODY_PITBULL",
  "DRIVER_BODY_ROMAN",
  "DRIVER_BODY_RUSK",
  "DRIVER_BODY_SCREWIE_LEWIE",
  "DRIVER_BODY_STELLA",
  "DRIVER_BODY_STIG",
  "DRIVER_BODY_TWINS_R",
  "DRIVER_BODY_TWINS_L",
  "DRIVER_BODY_VAL",
  "DRIVER_BODY_VLAD"
}
lookup_driver_model = {
  "Max Damage",
  "Die Anna",
  "ED 101",
  "Brother Grim",
  "Brother Grim Puppet",
  "Halfwit Harry",
  "Ivan The Bastard",
  "Kutter",
  "Neotwig",
  "Nora Virus",
  "Nutkenz",
  "Otis P Jivefunk",
  "Psycho Pitbull",
  "Roman",
  "Rusk",
  "Screwie Lewie",
  "Stella Stunner",
  "Stig O'Sore",
  "Twins (Right)",
  "Twins (Left)",
  "Val Hella",
  "Vlad"
}
lookup_car_selection_arcade = {
  txt.fe_chosen_ucase,
  txt.fe_random_ucase,
  txt.fe_eagles_only_ucase
}
values_car_selection_arcade = {
  "chosen",
  "random",
  "eagles_only"
}
function value_to_lookup(value, values, lookup)
  local index
  for i, data in ipairs(values) do
    if value == data then
      index = i
    end
  end
  if not index then
    return ""
  else
    return lookup[index]
  end
end
function get_stealing_ticker(value)
  return value_to_lookup(value, values_stealing, lookup_stealing)
end
function get_event_order_ticker(value)
  return value_to_lookup(value, values_event_order, lookup_event_order)
end
function get_grid_start_ticker(value)
  return value_to_lookup(value, values_grid_start, lookup_grid_start)
end
function get_powerups_ticker(value)
  return value_to_lookup(value, values_powerups, lookup_powerups)
end
function get_car_selection_ticker(value)
  return value_to_lookup(value, values_car_selection, lookup_car_selection)
end
function get_limit_car_ticker(value)
  return value_to_lookup(value, values_limit_car_selection, lookup_limit_car_selection)
end
function populate_grid_start(items, mp)
  items[#items + 1] = info_header_paged({
    text = txt.ui_fe_grid_start_ucase
  })
  local mode_list = progress_manager.get_mode_list()
  for i = 1, #mode_list do
    local game_mode = mode_list[i].game_mode
    local locked = mode_list[i].locked
    if not locked then
      local skip = false
      if game_mode == "classic" or game_mode == "death_race" or mp and game_mode == "ped_chase" then
        skip = true
      end
      if not skip then
        local item_id = id["grid_start_" .. game_mode]
        local text = game_rules[game_mode].game_rules_name
        local prefix = "profile_grid_start_" .. game_mode
        local property_watch = mp and prefix .. mp or prefix
        items[#items + 1] = spin_box_paged({
          id = item_id,
          text = text,
          property_watch = property_watch,
          values = values_grid_start,
          lookup = lookup_grid_start
        })
      end
    end
  end
  return items
end
function get_grid_start_item(items, game_mode)
  local item_id = id["grid_start_" .. game_mode]
  local text = txt.ui_fe_grid_start_ucase
  local property_watch = "profile_grid_start_" .. game_mode .. "_mp"
  items[#items + 1] = spin_box_paged({
    id = item_id,
    text = text,
    property_watch = property_watch,
    values = values_grid_start,
    lookup = lookup_grid_start
  })
  return items
end
function get_stealing_item(items, game_mode, text)
  local item_id = id["grid_start_" .. game_mode]
  local property_watch = "profile_point_stealing_" .. game_mode .. "_mp"
  items[#items + 1] = check_box_paged({
    id = item_id,
    text = text,
    property_watch = property_watch
  })
  return items
end
function populate_multiplayer_options(items)
  local mode_list = progress_manager.get_mode_list()
  for i = 1, #mode_list do
    local game_mode = mode_list[i].game_mode
    local locked = mode_list[i].locked
    if not locked then
      local game_mode_text = game_rules[game_mode].game_rules_name
      if game_mode == "car_crusher" then
        items[#items + 1] = info_header_paged({text = game_mode_text})
        items = get_grid_start_item(items, game_mode)
      elseif game_mode == "death_race" then
        items[#items + 1] = info_header_paged({text = game_mode_text})
        items = get_stealing_item(items, game_mode, txt.ui_fe_lap_stealing_ucase)
      elseif game_mode == "fox_n_hounds" then
        items[#items + 1] = info_header_paged({text = game_mode_text})
        items = get_grid_start_item(items, game_mode)
        items = get_stealing_item(items, game_mode, txt.ui_fe_time_stealing_ucase)
      elseif game_mode == "checkpoint_stampede" then
        items[#items + 1] = info_header_paged({text = game_mode_text})
        items = get_grid_start_item(items, game_mode)
        items = get_stealing_item(items, game_mode, txt.ui_fe_point_stealing_ucase)
      end
    end
  end
  return items
end
function populate_cheats(items)
  items[#items + 1] = check_box_paged({
    id = id.ai_cars,
    text = "Disable Opponents", --txt.ui_fe_pre_release_cheats_disable_ai_cars_ucase,
    property_watch = "ai_cars",
    inverse = true
  })
  items[#items + 1] = check_box_paged({
    id = id.race_timer,
    text = "Disable Race Timer", --txt.ui_fe_pre_release_cheats_disable_race_timer_ucase,
    property_watch = "race_timer",
    inverse = true
  })
  items[#items + 1] = check_box_paged({
    id = id.pedestrians,
    text = "Disable Peds", -- txt.ui_fe_pre_release_cheats_disable_pedestrians_ucase,
    property_watch = "peds",
    inverse = true
  })
  items[#items + 1] = check_box_paged({
    id = id.free_pis,
    text = "PIS Overdraft", --txt.ui_fe_pre_release_cheats_free_pis_ucase,
    property_watch = "arcade_allow_loss_on_pup_buy"
  })
  items[#items + 1] = spin_box_paged({
    id = id.driver_model,
    text = "Driver",
    property_watch = "player1_driver",
    values = values_driver_model,
    lookup = lookup_driver_model
  })
end
function populate_arcade()
  return function(menu)
    local items = {}
    items[#items + 1] = spin_box_paged({
      id = id.event_order,
      text = txt.ui_fe_event_order_ucase,
      property_watch = "profile_event_order",
      values = values_event_order,
      lookup = lookup_event_order
    })
    items[#items + 1] = spin_box_paged({
      id = id.starting_credit,
      text = txt.ui_fe_starting_credit_ucase,
      property_watch = "profile_starting_credit",
      values = lookup_starting_credit
    })
    items[#items + 1] = spin_box_paged({
      id = id.powerups,
      text = txt.ui_fe_powerups_ucase,
      property_watch = "profile_powerups",
      values = values_powerups,
      lookup = lookup_powerups
    })
    items[#items + 1] = spin_box_paged({
      id = id.pis_purchase,
      text = txt.ui_fe_pis_purchase_ucase,
      property_watch = "profile_pis_purchase",
      values = values_pis_purchase,
      lookup = lookup_pis_purchase
    })
    items[#items + 1] = spin_box_paged({
      id = id.car_selection,
      text = txt.ui_fe_car_select_ucase,
      property_watch = "profile_car_selection",
      values = values_car_selection_arcade,
      lookup = lookup_car_selection_arcade
    })
	populate_cheats(items)
    items = populate_grid_start(items)
    menu:send_item_message(id.options_list, message.set_new_content, {content = items})
  end
end
function populate_multiplayer()
  return function(menu)
    local items = {}
    items[#items + 1] = spin_box_paged({
      id = id.event_order,
      text = txt.ui_fe_event_order_ucase,
      property_watch = "profile_event_order_mp",
      values = values_event_order,
      lookup = lookup_event_order
    })
    items[#items + 1] = spin_box_paged({
      id = id.starting_credit,
      text = txt.ui_fe_starting_credit_ucase,
      property_watch = "profile_starting_credit_mp",
      values = lookup_starting_credit
    })
    items[#items + 1] = spin_box_paged({
      id = id.powerups,
      text = txt.ui_fe_powerups_ucase,
      property_watch = "profile_powerups_mp",
      values = values_powerups,
      lookup = lookup_powerups
    })
    items[#items + 1] = spin_box_paged({
      id = id.pis_purchase,
      text = txt.ui_fe_pis_purchase_ucase,
      property_watch = "profile_pis_purchase_mp",
      values = values_pis_purchase,
      lookup = lookup_pis_purchase
    })
    items = populate_multiplayer_options(items)
    menu:send_item_message(id.options_list, message.set_new_content, {content = items})
  end
end
